Transaction

Type Alias Transaction 

pub type Transaction = Transaction<TempoTxEnvelope>;

Aliased Type

pub struct Transaction {
    pub inner: Recovered<TempoTxEnvelope>,
    pub block_hash: Option<FixedBytes<32>>,
    pub block_number: Option<u64>,
    pub transaction_index: Option<u64>,
    pub effective_gas_price: Option<u128>,
    pub block_timestamp: Option<u64>,
}

Fields

inner: Recovered<TempoTxEnvelope>

The inner transaction object

block_hash: Option<FixedBytes<32>>

Hash of block where transaction was included, None if pending

block_number: Option<u64>

Number of block where transaction was included, None if pending

transaction_index: Option<u64>

Transaction Index

effective_gas_price: Option<u128>

Deprecated effective gas price value.

block_timestamp: Option<u64>

The Unix block_timestamp (in seconds) when the block containing this transaction was mined.

None if the transaction is pending.

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 944 bytes